@@ -1,8 +1,8 @@
 /*
-  $Id: ServerBase.h 12552 2011-07-18 10:47:45Z sloot $
+  $Id: ServerBase.h 15059 2012-08-08 08:27:17Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/TimblServer/include/timblserver/ServerBase.h $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -31,7 +31,7 @@
 #define SERVERBASE_H
 
 #include "timbl/TimblAPI.h"
-#include "timbl/LogStream.h"
+#include "ticcutils/LogStream.h"
 #include "timblserver/SocketBasics.h"
 
 namespace TimblServer {
@@ -41,7 +41,7 @@ namespace TimblServer {
     friend ServerClass *CreateServerPimpl( Timbl::AlgorithmType, 
 					   Timbl::GetOptClass * );
   public:
-    LogStream myLog;
+    TiCC::LogStream myLog;
     bool doDebug() { return debug; };
     bool doSetOptions( Timbl::TimblExperiment *, const std::string&  );
     bool classifyOneLine( Timbl::TimblExperiment *, const std::string& );
