@@ -1,8 +1,8 @@
 /*
-  $Id: ClientBase.cxx 12589 2011-07-19 12:52:06Z sloot $
+  $Id: ClientBase.cxx 15086 2012-08-09 10:03:00Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/TimblServer/src/ClientBase.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -58,10 +58,10 @@ namespace TimblServer {
       string names = line.substr( 17 );
       //      cerr << "step 1 '" << names << "'" << endl;
       vector<string> name;
-      if ( Timbl::split_at( names, name, " " ) > 0 ){
+      if ( TiCC::split_at( names, name, " " ) > 0 ){
 	for ( size_t i=0; i < name.size(); ++i ){
 	  //	  cerr << "step 2 i= " << i << " '" << name[i] << "'" << endl;
-	  bases.insert( Timbl::compress(name[i]) );
+	  bases.insert( TiCC::trim(name[i]) );
 	}
 	return true;
       }
