@@ -1,8 +1,8 @@
 /*
-  $Id: ServerBase.cxx 13726 2011-12-20 11:12:52Z sloot $
+  $Id: ServerBase.cxx 15059 2012-08-08 08:27:17Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/TimblServer/src/ServerBase.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -42,6 +42,7 @@
 #include "timblserver/ServerBase.h"
 
 using namespace std;
+using namespace TiCC;
 using namespace Timbl;
 
 namespace TimblServer {
@@ -388,7 +389,7 @@ namespace TimblServer {
     string baseName;
     *os << "Welcome to the Timbl server." << endl;
     if ( args->experiments->empty() ){
-      baseName == "default";
+      baseName = "default";
       *Dbg(theServer->myLog) << " Voor Create Default Client " << endl;
       Chld = createClient( theServer->theExp(), sock );
       *Dbg(theServer->myLog) << " Na Create Client " << endl;
