@@ -1,8 +1,8 @@
 /*
-  $Id: SocketBasics.cxx 13735 2011-12-20 15:58:39Z sloot $
+  $Id: SocketBasics.cxx 15197 2012-09-18 10:23:24Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/TimblServer/src/SocketBasics.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -324,6 +324,7 @@ namespace Sockets {
 	setsockopt( sock, IPPROTO_TCP, TCP_NODELAY, (void *)&val, sizeof(val) );
 	if ( ::connect( sock, aip->ai_addr, aip->ai_addrlen ) < 0 ){
 	  close( sock );
+	  sock = -1;
 	  mess = string( "ClientSocket: Connection on ") + hostString + ":"
 	    + Timbl::toString(sock) + " failed (" + strerror(errno) + ")";
 	}
@@ -377,7 +378,7 @@ namespace Sockets {
   bool ServerSocket::accept( ServerSocket& newSocket ){
     newSocket.sock = -1;
     struct sockaddr_storage cli_addr;
-    TIMBL_SOCKLEN_T clilen = sizeof(cli_addr);
+    socklen_t clilen = sizeof(cli_addr);
     int newsock = ::accept( sock, (struct sockaddr *)&cli_addr, &clilen );
     if( newsock < 0 ){
       if ( errno == EINTR )
@@ -501,7 +502,7 @@ namespace Sockets {
   bool ServerSocket::accept( ServerSocket& newSocket ){
     newSocket.sock = -1;
     struct sockaddr_storage cli_addr;
-    TIMBL_SOCKLEN_T clilen = sizeof(cli_addr);
+    socklen_t clilen = sizeof(cli_addr);
     int newsock = ::accept( sock, (struct sockaddr *)&cli_addr, &clilen );
     if( newsock < 0 ){
       if ( errno == EINTR )
@@ -513,7 +514,7 @@ namespace Sockets {
     else {
       string clientname;
       struct sockaddr_in rem;
-      TIMBL_SOCKLEN_T remlen = sizeof(rem);
+      socklen_t remlen = sizeof(rem);
       if ( getpeername( newsock, (struct sockaddr *)&rem, &remlen ) >= 0 ){
 	struct hostent *host = gethostbyaddr( (char *)&rem.sin_addr,
 					      sizeof rem.sin_addr,
