@@ -1,8 +1,8 @@
 /*
-  $Id: TimblServer.cxx 9351 2011-04-07 14:47:29Z sloot $
+  $Id: TimblServer.cxx 15086 2012-08-09 10:03:00Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/TimblServer/src/TimblServer.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -287,7 +287,7 @@ bool get_file_names( TimblOpts& Opts ){
     if ( !string_to( value, W ) ){
       // No valid weighting, so assume it also has a filename
       vector<string> parts;
-      size_t num = split_at( value, parts, ":" );
+      size_t num = TiCC::split_at( value, parts, ":" );
       if ( num == 2 ){
 	if ( !string_to( parts[1], W ) ){
 	  cerr << "invalid weighting option: " << value << endl;
@@ -328,7 +328,7 @@ int main(int argc, char *argv[]){
     // Start.
     //
     cerr << "TiMBL Server " << TimblServer::Version()
-	 << " (c) ILK 1998 - 2011.\n" 
+	 << " (c) ILK 1998 - 2012.\n" 
 	 << "Tilburg Memory Based Learner\n"
 	 << "Induction of Linguistic Knowledge Research Group, Tilburg University\n"
 	 << "CLiPS Computational Linguistics Group, University of Antwerp\n" 
